#
# spec file for package tclap
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?suse_version} >= 1000
%define with_doc 1
%else
%define with_doc 0
%endif

Name:           tclap
Version:        1.2.1
Release:        15.2
License:        MIT
Summary:        Templatized C++ Command Line Parser
Url:            http://tclap.sf.net
Group:          Development/Libraries/C and C++
# http://prdownloads.sourceforge.net/tclap/tclap-%%{version}.tar.gz
Source:         tclap-%{version}.tar.bz2
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch1:         tclap-remove_Wextra.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %with_doc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  graphviz
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
Provides:       libtclap = %{version}
Provides:       libtclap-devel = %{version}
%endif #with_doc
%if 0%{?suse_version} >= 1030
BuildRequires:  fdupes
%endif

%description
TCLAP is a small, flexible library that provides a simple interface for
defining and accessing command line arguments. It was intially inspired by the
user friendly CLAP libary. The difference is that this library is templatized,
so the argument class is type independent. Type independence avoids
identical-except-for-type objects, such as IntArg, FloatArg, and StringArg.
While the library is not strictly compliant with the GNU or POSIX standards, it
is close.

%if %with_doc
%package doc
Summary:        API Documentation for %{name}
Group:          Development/Libraries/C and C++

%description doc
This package contains the API documentation for TCLAP, the Templatized
C++ Command Line Parser.
%endif #with_doc

%prep
%setup -q
%if 0%{?suse_version} < 1000
%patch1
%endif

%build
%configure \
%if %with_doc
	 --enable-doxygen
%else
	 --disable-doxygen
%endif #with_doc

make %{?_smp_mflags}

%install
%make_install

install -d "%{buildroot}%{_docdir}/%{name}"

%if %with_doc
mv "%{buildroot}%{_datadir}/doc/tclap" "%{buildroot}%{_docdir}/%{name}/html"
rm -rf "%{buildroot}%{_docdir}/%{name}/html/html/CVS"
%endif #with_doc

echo -n > docfiles.lst
for f in AUTHORS ChangeLog COPYING NEWS README; do
	 install -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$f"
	 echo "%doc %{_docdir}/%{name}/${f}" >> docfiles.lst
done

%if %with_doc
%if 0%{?suse_version} >= 1030
%fdupes -s "%{buildroot}%{_docdir}/%{name}/html"
%endif
%endif #with_doc

%clean
rm -rf %{buildroot}

%files -f docfiles.lst
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}
%{_includedir}/tclap
%{_libdir}/pkgconfig/tclap.pc

%if %with_doc
%files doc
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/html
%endif #with_doc

%changelog
* Fri Oct 21 2011 tony@daylessday.org
- Updated to version 1.2.1. Several minor bugs and memory leaks were fixed.
* Sat Sep 24 2011 andreas.stieger@gmx.de
- remove dependency on licenses, not in factory anymore
* Sat Jan  9 2010 pascal.bleser@opensuse.org
- initial package (1.2.0)
